Coverage for C:\src\imod-python\imod\mf6\gwfgwt.py: 94%

1 from copy import deepcopy

2 from typing import Optional

3

4 import cftime

5 import numpy as np

6

7 from imod.logging import init_log_decorator

8 from imod.mf6.exchangebase import ExchangeBase

9 from imod.mf6.package import Package

10 from imod.typing import GridDataArray

11

12

13 class GWFGWT(ExchangeBase):

14 _pkg_id = "gwfgwt"

15

16 _template = Package._initialize_template(_pkg_id)

17

18 @init_log_decorator()

19 def __init__(self, model_id1: str, model_id2: str):

20 dict_dataset = {

21 "model_name_1": model_id1,

22 "model_name_2": model_id2,

23 }

24

25 super().__init__(dict_dataset)

26

27 def clip_box(

28 self,

29 time_min: Optional[cftime.datetime | np.datetime64 | str] = None,

30 time_max: Optional[cftime.datetime | np.datetime64 | str] = None,

31 layer_min: Optional[int] = None,

32 layer_max: Optional[int] = None,

33 x_min: Optional[float] = None,

34 x_max: Optional[float] = None,

35 y_min: Optional[float] = None,

36 y_max: Optional[float] = None,

37 top: Optional[GridDataArray] = None,

38 bottom: Optional[GridDataArray] = None,

39 ) -> Package:

40 """

41 The GWF-GWT exchange does not have any spatial coordinates that can be clipped.

42 """

43 return deepcopy(self)